@@ -12,10 +12,11 @@ def check_latest_version():
     """Check if the latest version is installed and document how to update if needed."""
     config = yaml_parser.parse_config()
 
-    package_name = config['static']['app_name']
+    # package_name = config['static']['app_name']
+    package_name = "robin_sd_upload"
     current_version = _version.__version__
     
-    latest_version = pypi_simple.get_latest_package_version(package_name)
+    latest_version = pypi_simple.package(package_name).version
 
     if current_version == latest_version:
         logger.log(message="Latest version detected, proceeding.", log_level="info", to_file=True, to_terminal=False)
